@@ -65,6 +65,13 @@ def videos(args):
         for video in videos["edges"]:
             print_video(video["node"])
 
+        if not args.pager:
+            print_out(
+                "\n<dim>There are more videos. "
+                "Increase the --limit or use --pager to see the rest.</dim>"
+            )
+            break
+
         if not has_more or not _continue():
             break
 
@@ -83,6 +90,10 @@ def _parse_playlists(playlists_m3u8):
 
 
 def _get_playlist_by_name(playlists, quality):
+    if quality == "source":
+        _, _, uri = playlists[0]
+        return uri
+
     for name, _, uri in playlists:
         if name == quality:
             return uri
@@ -102,7 +113,7 @@ def _select_playlist_interactive(playlists):
     return uri
 
 
-def _join_vods(playlist_path, target):
+def _join_vods(playlist_path, target, overwrite, no_overwrite):
     command = [
         "ffmpeg",
         "-i", playlist_path,
@@ -112,6 +123,9 @@ def _join_vods(playlist_path, target):
         "-loglevel", "warning",
     ]
 
+    if overwrite:
+        command.append("-y")
+
     print_out("<dim>{}</dim>".format(" ".join(command)))
     result = subprocess.run(command)
     if result.returncode != 0:
@@ -193,6 +207,9 @@ def _get_clip_url(clip, args):
 
     # Quality given as an argument
     if args.quality:
+        if args.quality == "source":
+            return qualities[0]["sourceURL"]
+
         selected_quality = args.quality.rstrip("p")  # allow 720p as well as 720
         for q in qualities:
             if q["quality"] == selected_quality:
@@ -294,9 +311,14 @@ def _download_video(video_id, args):
     playlist_path = path.join(target_dir, "playlist_downloaded.m3u8")
     playlist.dump(playlist_path)
 
+    if args.no_join:
+        print_out("\n\n<dim>Skipping joining files...</dim>")
+        print_out("VODs downloaded to:\n<blue>{}</blue>".format(target_dir))
+        return
+
     print_out("\n\nJoining files...")
     target = _video_target_filename(video, args.format)
-    _join_vods(playlist_path, target)
+    _join_vods(playlist_path, target, args.overwrite)
 
     if args.keep:
         print_out("\n<dim>Temporary files not deleted: {}</dim>".format(target_dir))
